# AppModule for SpeakOn
# Author: Isaac Porat
# Ideally, touch handler should be disabled on focus gained and   enabled again on focus lost together with sleepMode handling
# Unfortunatly this was impossible with NVDA at the time with version 2015.1
# Instead first the approach taken  was to disable touchHandler on __init__ and enable it again on terminate 
# This is because with sleepMode On both the focus lost and gained methods are never called
# The drawback of this approach is that touchHandler is disabled when SpeakOn is running even when it loses focus
# It turned out that __init__ is not always called once SpeakOn has been run once
# Therefore a hybrid approach was taken using the focus gained method which is called only once after
# sleepMode is set but seems to work reliably  

import appModuleHandler
import touchHandler
from logHandler import log

class AppModule(appModuleHandler.AppModule):
	
	# Note this method is called only once before sleepMode is enabled
	def event_appModule_gainFocus(self):
		log.info("SpeakOn gained focus")
		self.sleepMode = True
		try:
			if touchHandler.handler != None:
				touchHandler.terminate()
		except NotImplementedError:
			pass # Ignore, expected without touch device

	def terminate(self):
		log.info("SpeakOn module terminated")
		try:
			if touchHandler.handler == None:
				touchHandler.initialize()
		except NotImplementedError:
			pass # Ignore, expected without touch device


